@@ -9,15 +9,19 @@ FILE="$3"
 FILE="$(readlink -f $FILE)"
 PKG=`dpkg-parsechangelog|grep ^Source:|sed 's/^Source: //'`
 REPACK_DIR="$PKG-$VER.orig" # DevRef § 6.7.8.2
-DIR=`mktemp -d ./tmpRepackXXXXXX`
-DIR=$(readlink -f $DIR)
-trap "rm -rf \"$DIR\"" QUIT INT EXIT
+
+WORKDIR=`mktemp -d`
+WORKDIR=$(readlink -f $WORKDIR)
+trap "rm -rf \"$WORKDIR\"" QUIT INT EXIT
 FINAL="$(dirname $FILE)/${PKG}_$VER.orig.tar.gz"
-mkdir $REPACK_DIR
-cd $REPACK_DIR
-unzip xf $FILE 2>/dev/null
+
+mkdir $WORKDIR/$REPACK_DIR
+cd $WORKDIR/$REPACK_DIR
+unzip $FILE > /dev/null
 cd ..
+
 tar cf new.tar $REPACK_DIR
 gzip -9 new.tar
 mv new.tar.gz $FINAL
+
 echo "Repacked to ../$(basename $FINAL)"
